@@ -24,21 +24,4 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-
 #pragma once
-
-#include "messagereceiver.h"
-
-class CliMain : public MessageReceiver
-{
-public:
-	CliMain();
-	virtual ~CliMain();
-
-	int run(int argc, char* argv[]);
-	void handleMessage(Message* msg);
-
-private:
-	bool loading;
-};
-
