@@ -28,6 +28,7 @@
 
 #include <cstring>
 #include <algorithm>
+#include <string>
 
 #include <midievent.h>
 
@@ -62,7 +63,7 @@ DrumGizmoPlugin::DrumGizmoPlugin()
 	init();
 
 	drumgizmo = std::make_shared<DrumGizmo>(settings, output, input);
-	resizeWindow(370, 330);
+	resizeWindow(width, height);
 	drumgizmo->setFreeWheel(true);
 	drumgizmo->setSamplerate(44100);
 	drumgizmo->setFrameSize(2048);
@@ -185,12 +186,11 @@ public:
 	{
 	}
 
-	GUI::PixelBufferAlpha& GetPixelBuffer()
+	// From Canvas:
+	GUI::PixelBufferAlpha& GetPixelBuffer() override
 	{
 		return pixbuf;
 	}
-	void beginPaint() {}
-	void endPaint() {}
 
 private:
 	InlinePixelBufferAlpha pixbuf;
@@ -259,11 +259,13 @@ bool DrumGizmoPlugin::hasGUI()
 	return true;
 }
 
-void DrumGizmoPlugin::createWindow(void *parent)
+void* DrumGizmoPlugin::createWindow(void *parent)
 {
-	plugin_gui = std::make_shared<GUI::PluginGUI>(settings, parent);
-	resizeWindow(370, 330);
+	plugin_gui = std::make_shared<GUI::MainWindow>(settings, parent);
+	resizeWindow(width, height);
 	onShowWindow();
+
+	return plugin_gui->getNativeWindowHandle();
 }
 
 void DrumGizmoPlugin::onDestroyWindow()
@@ -464,6 +466,13 @@ std::string bool2str(bool a)
 	return a?"true":"false";
 }
 
+std::string int2str(int a)
+{
+	char buf[256];
+	snprintf(buf, sizeof(buf) - 1, "%d", a);
+	return buf;
+}
+
 float str2float(std::string a)
 {
 	if(a == "")
@@ -474,6 +483,18 @@ float str2float(std::string a)
 	return atof_nol(a.c_str());
 }
 
+int str2int(std::string a)
+{
+	try
+	{
+		return std::stoi(a);
+	}
+	catch(...)
+	{
+		return 0;
+	}
+}
+
 } // end anonymous namespace
 
 DrumGizmoPlugin::ConfigStringIO::ConfigStringIO(Settings& settings)
@@ -498,6 +519,14 @@ std::string DrumGizmoPlugin::ConfigStringIO::get()
 		bool2str(settings.enable_velocity_randomiser.load()) + "</value>\n"
 		"  <value name=\"velocity_randomiser_weight\">" +
 		float2str(settings.velocity_randomiser_weight.load()) + "</value>\n"
+		"  <value name=\"enable_resampling\">" +
+		bool2str(settings.enable_resampling.load()) + "</value>\n"
+		"  <value name=\"disk_cache_upper_limit\">" +
+		int2str(settings.disk_cache_upper_limit.load()) + "</value>\n"
+		"  <value name=\"disk_cache_chunk_size\">" +
+		int2str(settings.disk_cache_chunk_size.load()) + "</value>\n"
+		"  <value name=\"disk_cache_enable\">" +
+		bool2str(settings.disk_cache_enable.load()) + "</value>\n"
 		"</config>";
 }
 
@@ -542,6 +571,21 @@ bool DrumGizmoPlugin::ConfigStringIO::set(std::string config_string)
 		settings.enable_resampling.store(p.value("enable_resampling") == "true");
 	}
 
+	if(p.value("disk_cache_upper_limit") != "")
+	{
+		settings.disk_cache_upper_limit.store(str2int(p.value("disk_cache_upper_limit")));
+	}
+
+	if(p.value("disk_cache_chunk_size") != "")
+	{
+		settings.disk_cache_chunk_size.store(str2int(p.value("disk_cache_chunk_size")));
+	}
+
+	if(p.value("disk_cache_enable") != "")
+	{
+		settings.disk_cache_enable.store(p.value("disk_cache_enable") == "true");
+	}
+
 	std::string newkit = p.value("drumkitfile");
 	if(newkit != "")
 	{
