@@ -28,15 +28,6 @@
 
 #include <memory>
 
-#if defined(X11)
-#include <X11/Xlib.h>
-#endif // defined(X11)
-
-#if defined(WIN32)
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#endif // defined(WIN32)
-
 #ifdef LV2
 #include <pluginlv2.h>
 #endif
@@ -48,7 +39,7 @@
 #include <drumgizmo.h>
 #include <audioinputenginemidi.h>
 #include <audiooutputengine.h>
-#include <plugingui.h>
+#include <mainwindow.h>
 
 #include <texturedbox.h>
 #include <imagecache.h>
@@ -109,7 +100,7 @@ public:
 	// GUI
 	//
 	bool hasGUI() override;
-	void createWindow(void *parent) override;
+	void* createWindow(void *parent) override;
 	void onDestroyWindow() override;
 	void onShowWindow() override;
 	void onHideWindow() override;
@@ -188,27 +179,30 @@ private:
 	SettingsGetter settingsGetter{settings};
 
 	GUI::ImageCache imageCache;
-	GUI::TexturedBox box{imageCache, ":progress.png",
+	GUI::TexturedBox box{imageCache, ":resources/progress.png",
 			0, 0, // atlas offset (x, y)
 			6, 1, 6, // dx1, dx2, dx3
 			11, 0, 0}; // dy1, dy2, dy3
 
-	GUI::TexturedBox bar_red{imageCache, ":progress.png",
+	GUI::TexturedBox bar_red{imageCache, ":resources/progress.png",
 			13, 0, // atlas offset (x, y)
 			2, 1, 2, // dx1, dx2, dx3
 			11, 0, 0}; // dy1, dy2, dy3
 
-	GUI::TexturedBox bar_green{imageCache, ":progress.png",
+	GUI::TexturedBox bar_green{imageCache, ":resources/progress.png",
 			18, 0, // atlas offset (x, y)
 			2, 1, 2, // dx1, dx2, dx3
 			11, 0, 0}; // dy1, dy2, dy3
 
-	GUI::TexturedBox bar_blue{imageCache, ":progress.png",
+	GUI::TexturedBox bar_blue{imageCache, ":resources/progress.png",
 			23, 0, // atlas offset (x, y)
 			2, 1, 2, // dx1, dx2, dx3
 			11, 0, 0}; // dy1, dy2, dy3
 
-	std::shared_ptr<GUI::PluginGUI> plugin_gui;
+	std::shared_ptr<GUI::MainWindow> plugin_gui;
 	std::shared_ptr<DrumGizmo> drumgizmo;
 	std::uint32_t inlineDisplayBuffer[1024*1024];
+
+	static constexpr std::size_t width{750};
+	static constexpr std::size_t height{400};
 };
