@@ -177,7 +177,7 @@ public:
 	}
 
 	//! Create new window.
-	virtual void createWindow(void *parent) {}
+	virtual void* createWindow(void *parent) { return nullptr; }
 
 	//! Destroy window.
 	virtual void onDestroyWindow() {}
