@@ -542,7 +542,7 @@ LV2UI_Handle PluginLV2::uiInstantiate(const struct _LV2UI_Descriptor*descriptor,
 
 	plugin_lv2->resize = resize;
 
-	plugin_lv2->createWindow(parent);
+	*widget = plugin_lv2->createWindow(parent);
 
 	return plugin_lv2;
 }
