@@ -65,7 +65,7 @@ public:
 	float getSamplerate() override;
 
 	//! This method is called by the host when the samplerate changes.
-	virtual void onSamplerateChange(float samplerate) = 0;
+	virtual void onSamplerateChange(float samplerate) override = 0;
 
 	//! Call this to get current frame-size.
 	std::size_t getFramesize() override;
@@ -129,14 +129,14 @@ public:
 	                     std::vector<MidiEvent>& output_events,
 	                     const std::vector<const float*>& input_samples,
 	                     const std::vector<float*>& output_samples,
-	                     std::size_t count) = 0;
+	                     std::size_t count) override = 0;
 
 	//
 	// Inline GUI (optional)
 	//
 
 	//! Return true if a GUI implementation is to be used.
-	virtual bool hasInlineGUI()
+	virtual bool hasInlineGUI() override
 	{
 		return false;
 	}
@@ -148,7 +148,7 @@ public:
 	//! \param context The render context filled an maintained by the plugin.
 	virtual void onInlineRedraw(std::size_t width,
 	                            std::size_t max_height,
-	                            InlineDrawContext& context) {}
+	                            InlineDrawContext& context) override {}
 
 	//
 	// GUI (optional)
@@ -161,7 +161,7 @@ public:
 	}
 
 	//! Create new window.
-	virtual void createWindow(void *parent) override {}
+	virtual void* createWindow(void *parent) override { return nullptr; }
 
 	//! Destroy window.
 	virtual void onDestroyWindow() override {}
