@@ -153,7 +153,7 @@ public:
 	}
 
 	//! Create new window.
-	virtual void createWindow(void *parent) override {}
+	virtual void* createWindow(void *parent) override { return nullptr; }
 
 	//! Destroy window.
 	virtual void onDestroyWindow() override {}
