@@ -37,36 +37,43 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 
+#include <platform.h>
 #include <hugin.hpp>
 
 #ifdef __MINGW32__
 #include <direct.h>
 #endif
 
-namespace GUI {
+namespace GUI
+{
 
-FileBrowser::FileBrowser(Widget *parent)
-	: Widget(parent)
+FileBrowser::FileBrowser(Widget* parent)
+	: Dialog(parent, true)
 	, dir(Directory::cwd())
 	, lbl_path(this)
 	, lineedit(this)
 	, listbox(this)
 	, btn_sel(this)
 	, btn_esc(this)
-	, back(":bg.png")
+	, back(":resources/bg.png")
 {
-#ifdef WIN32
+#if DG_PLATFORM == DG_PLATFORM_WINDOWS
 	above_root = false;
 #endif
 
+	setCaption("Open file...");
+
 	lbl_path.setText("Path:");
 
 	//lineedit.setReadOnly(true);
 	CONNECT(&lineedit, enterPressedNotifier, this, &FileBrowser::handleKeyEvent);
 	CONNECT(&listbox, selectionNotifier,
 	        this, &FileBrowser::listSelectionChanged);
+	CONNECT(this, fileSelectNotifier,
+	        this, &FileBrowser::select);
+	CONNECT(eventHandler(), closeNotifier,
+	        this, &FileBrowser::cancel);
 
 	btn_sel.setText("Select");
 	CONNECT(&btn_sel, clickNotifier, this, &FileBrowser::selectButtonClicked);
@@ -77,10 +84,6 @@ FileBrowser::FileBrowser(Widget *parent)
 	changeDir();
 }
 
-FileBrowser::~FileBrowser()
-{
-}
-
 void FileBrowser::setPath(const std::string& path)
 {
 	INFO(filebrowser, "Setting path to '%s'\n", path.c_str());
@@ -99,9 +102,9 @@ void FileBrowser::setPath(const std::string& path)
 	changeDir();
 }
 
-void FileBrowser::resize(int w, int h)
+void FileBrowser::resize(std::size_t width, std::size_t height)
 {
-	Widget::resize(w,h);
+	Dialog::resize(width, height);
 
 	int offset = 0;
 	int brd = 5; // border
@@ -109,24 +112,24 @@ void FileBrowser::resize(int w, int h)
 
 	offset += brd;
 
-	lbl_path.move(0, offset);
+	lbl_path.move(brd, offset);
 	lineedit.move(60, offset);
 
 	offset += btn_h;
 
 	lbl_path.resize(60, btn_h);
-	lineedit.resize(w - 60 - brd, btn_h);
+	lineedit.resize(width - 60 - brd, btn_h);
 
 	offset += brd;
 
 	listbox.move(brd, offset);
-	listbox.resize(w - 1 - 2*brd, h - btn_h - 2*brd - offset);
+	listbox.resize(width - 1 - 2*brd, height - btn_h - 2*brd - offset);
 
-	btn_esc.move(brd, h - btn_h - brd);
-	btn_esc.resize((w - 1 - 2*brd) / 2 - brd / 2, btn_h);
+	btn_esc.move(brd, height - btn_h - brd);
+	btn_esc.resize((width - 1 - 2*brd) / 2 - brd / 2, btn_h);
 
-	btn_sel.move(brd + w / 2 - brd / 2, h - btn_h - brd);
-	btn_sel.resize((w - 1 - 2*brd) / 2, btn_h);
+	btn_sel.move(brd + width / 2 - brd / 2, height - btn_h - brd);
+	btn_sel.resize((width - 1 - 2*brd) / 2, btn_h);
 }
 
 void FileBrowser::repaintEvent(RepaintEvent* repaintEvent)
@@ -154,7 +157,7 @@ void FileBrowser::handleKeyEvent()
 {
 	listbox.clearSelectedValue();
 
-	std::string value = lineedit.text();
+	std::string value = lineedit.getText();
 	if((value.size() > 1) && (value[0] == '@'))
 	{
 		DEBUG(filebrowser, "Selecting ref-file '%s'\n", value.c_str());
@@ -162,12 +165,21 @@ void FileBrowser::handleKeyEvent()
 		return;
 	}
 
-	dir.setPath(lineedit.text());
+	dir.setPath(lineedit.getText());
 	changeDir();
 }
 
 void FileBrowser::cancel()
 {
+	has_filename = false;
+	hide();
+	fileSelectCancelNotifier();
+}
+
+void FileBrowser::select(const std::string& file)
+{
+	has_filename = true;
+	filename = file;
 	hide();
 }
 
@@ -185,7 +197,7 @@ void FileBrowser::changeDir()
 	INFO(filebrowser, "Changing path to '%s'\n",
 	     (dir.path() + dir.seperator() + value).c_str());
 
-#ifdef WIN32
+#if DG_PLATFORM == DG_PLATFORM_WINDOWS
 	if(above_root && !value.empty())
 	{
 		dir.setPath(value + dir.seperator());
@@ -211,7 +223,7 @@ void FileBrowser::changeDir()
 
 	std::vector<ListBoxBasic::Item> items;
 
-#ifdef WIN32
+#if DG_PLATFORM == DG_PLATFORM_WINDOWS
 	if(Directory::isRoot(dir.path()) && (value == ".."))
 	{
 		DEBUG(filebrowser, "Showing partitions...\n");
@@ -257,4 +269,14 @@ void FileBrowser::changeDir()
 	listbox.addItems(items);
 }
 
+std::string FileBrowser::getFilename() const
+{
+	return filename;
+}
+
+bool FileBrowser::hasFilename() const
+{
+	return has_filename;
+}
+
 } // GUI::
