@@ -27,8 +27,9 @@
 #pragma once
 
 #include <notifier.h>
+#include <platform.h>
 
-#include "widget.h"
+#include "dialog.h"
 #include "button.h"
 #include "listbox.h"
 #include "lineedit.h"
@@ -36,21 +37,31 @@
 #include "image.h"
 #include "directory.h"
 
-namespace GUI {
+namespace GUI
+{
 
-class FileBrowser : public Widget {
+class FileBrowser
+	: public Dialog
+{
 public:
-	FileBrowser(Widget *parent);
-	~FileBrowser();
+	FileBrowser(Widget* parent);
 
 	void setPath(const std::string& path);
 
 	Notifier<const std::string&> fileSelectNotifier; // (const std::string& path)
+	Notifier<> fileSelectCancelNotifier;
 
 	// From Widget:
 	bool isFocusable() override { return true; }
 	virtual void repaintEvent(RepaintEvent* repaintEvent) override;
-	virtual void resize(int w, int h) override;
+	virtual void resize(std::size_t width, std::size_t height) override;
+
+	//! Return the filename selected in the browser.
+	std::string getFilename() const;
+
+	//! Returns true if the filebrowser has a selection, false if the window was
+	//! closed or the cancel button was clicked.
+	bool hasFilename() const;
 
 private:
 	void listSelectionChanged();
@@ -59,12 +70,13 @@ private:
 	void handleKeyEvent();
 
 	Directory dir;
-#ifdef WIN32
+#if DG_PLATFORM == DG_PLATFORM_WINDOWS
 	bool above_root;
 	bool in_root;
 #endif
 
 	void cancel();
+	void select(const std::string& file);
 	void changeDir();
 
 	Label lbl_path;
@@ -76,6 +88,9 @@ private:
 	Button btn_esc;
 
 	Image back;
+
+	bool has_filename{false};
+	std::string filename;
 };
 
 } // GUI::
