@@ -26,28 +26,31 @@
  */
 #pragma once
 
-#include <list>
 #include <cstdlib>
+#include <list>
+#include <unordered_map>
 
 #include <notifier.h>
 
-namespace GUI {
+namespace GUI
+{
 
 class Layout;
 
-class LayoutItem {
+class LayoutItem
+{
 public:
 	LayoutItem();
 	virtual ~LayoutItem();
 
 	void setLayoutParent(Layout* parent);
 
-	virtual void resize(int width, int height) = 0;
-	virtual void move(size_t x, size_t y) = 0;
-	virtual int x() = 0;
-	virtual int y() = 0;
-	virtual size_t width() = 0;
-	virtual size_t height() = 0;
+	virtual void resize(std::size_t width, std::size_t height) = 0;
+	virtual void move(int x, int y) = 0;
+	virtual int x() const = 0;
+	virtual int y() const = 0;
+	virtual std::size_t width() const = 0;
+	virtual std::size_t height() const = 0;
 
 private:
 	Layout* parent;
@@ -57,11 +60,13 @@ private:
 class Layout : public Listener
 {
 public:
-	Layout(LayoutItem *parent);
-	virtual ~Layout() {}
+	Layout(LayoutItem* parent);
+	virtual ~Layout()
+	{
+	}
 
-	virtual void addItem(LayoutItem *item);
-	virtual void removeItem(LayoutItem *item);
+	virtual void addItem(LayoutItem* item);
+	virtual void removeItem(LayoutItem* item);
 
 	//! \brief Reimplement this method to create a new Layout rule.
 	virtual void layout() = 0;
@@ -69,15 +74,16 @@ public:
 protected:
 	void sizeChanged(int width, int height);
 
-	LayoutItem *parent;
-	typedef std::list<LayoutItem *> LayoutItemList;
+	LayoutItem* parent;
+	typedef std::list<LayoutItem*> LayoutItemList;
 	LayoutItemList items;
 };
 
 //! \brief Abstract box layout
-class BoxLayout : public Layout {
+class BoxLayout : public Layout
+{
 public:
-	BoxLayout(LayoutItem *parent);
+	BoxLayout(LayoutItem* parent);
 
 	//! \brief Set to false to only move the items, not scale them.
 	void setResizeChildren(bool resize_children);
@@ -85,23 +91,25 @@ public:
 	void setSpacing(size_t spacing);
 
 	// From Layout:
-	virtual void layout() override  = 0;
+	virtual void layout() override = 0;
 
 protected:
 	bool resizeChildren{false};
 	size_t spacing{0};
 };
 
-enum class HAlignment {
+enum class HAlignment
+{
 	left,
 	center,
 	right,
 };
 
 //! \brief A Layout that lays out its elements vertically.
-class VBoxLayout : public BoxLayout {
+class VBoxLayout : public BoxLayout
+{
 public:
-	VBoxLayout(LayoutItem *parent);
+	VBoxLayout(LayoutItem* parent);
 
 	void setHAlignment(HAlignment alignment);
 
@@ -112,16 +120,18 @@ protected:
 	HAlignment align;
 };
 
-enum class VAlignment {
+enum class VAlignment
+{
 	top,
 	center,
 	bottom,
 };
 
 //! \brief A Layout that lays out its elements vertically.
-class HBoxLayout : public BoxLayout {
+class HBoxLayout : public BoxLayout
+{
 public:
-	HBoxLayout(LayoutItem *parent);
+	HBoxLayout(LayoutItem* parent);
 
 	void setVAlignment(VAlignment alignment);
 
@@ -132,4 +142,51 @@ protected:
 	VAlignment align;
 };
 
+//! \brief A Layout class which places the items in a regular grid. An item can
+//! span multiple rows/columns.
+class GridLayout : public BoxLayout
+{
+public:
+	// The range is open, i.e. end is one past the last one.
+	struct GridRange
+	{
+		int column_begin;
+		int column_end;
+		int row_begin;
+		int row_end;
+	};
+
+	GridLayout(LayoutItem* parent, std::size_t number_of_columns,
+	    std::size_t number_of_rows);
+
+	virtual ~GridLayout()
+	{
+	}
+
+	// From Layout:
+	virtual void removeItem(LayoutItem* item);
+	virtual void layout();
+
+	void setPosition(LayoutItem* item, GridRange const& range);
+
+protected:
+	std::size_t number_of_columns;
+	std::size_t number_of_rows;
+
+	// Note: Yes, this is somewhat redundant to the LayoutItemList of the Layout
+	// class. However, this was the best idea I had such that I could still
+	// derive from Layout. If you find this ugly, feel free to fix it.
+	std::unordered_map<LayoutItem*, GridRange> grid_ranges;
+
+private:
+	struct CellSize {
+		std::size_t width;
+		std::size_t height;
+	};
+
+	CellSize calculateCellSize() const;
+	void moveAndResize(
+	    LayoutItem& item, GridRange const& range, CellSize cell_size) const;
+};
+
 } // GUI::
