@@ -29,21 +29,23 @@
 #include <cmath>
 #include <cassert>
 
+#include "pixelbuffer.h"
+#include "font.h"
+#include "drawable.h"
+#include "image.h"
+#include "canvas.h"
+
 namespace GUI
 {
 
 Painter::Painter(Canvas& canvas)
-	: canvas(canvas)
-	, pixbuf(canvas.GetPixelBuffer())
+	: pixbuf(canvas.GetPixelBuffer())
 {
-	canvas.beginPaint();
 	colour = Colour(0.0f, 0.0f, 0.0f, 0.5f);
 }
 
 Painter::~Painter()
 {
-	canvas.endPaint();
-	flush();
 }
 
 void Painter::setColour(const Colour& colour)
@@ -54,7 +56,10 @@ void Painter::setColour(const Colour& colour)
 static void plot(PixelBufferAlpha& pixbuf, const Colour& colour,
                  int x, int y, double c)
 {
-	if((x >= (int)pixbuf.width) || (y >= (int)pixbuf.height))
+	if((x >= (int)pixbuf.width) ||
+	   (y >= (int)pixbuf.height) ||
+	   (x < 0) ||
+	   (y < 0))
 	{
 		return;
 	}
@@ -158,7 +163,7 @@ void Painter::drawRectangle(int x1, int y1, int x2, int y2)
 
 void Painter::drawFilledRectangle(int x1, int y1, int x2, int y2)
 {
-	for(int y = y1; y < y2; ++y)
+	for(int y = y1; y <= y2; ++y)
 	{
 		drawLine(x1, y, x2, y);
 	}
@@ -540,12 +545,4 @@ void Painter::drawBar(int x, int y, const Bar& bar, int width, int height)
 	                   bar.right->width(), height);
 }
 
-void Painter::flush()
-{
-#ifdef X11
-	// Send the "DrawLine" request to the server
-	//XFlush(gctx->display);
-#endif/*X11*/
-}
-
 } // GUI::
