@@ -24,56 +24,42 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#include "plugingui.h"
-
-#ifdef WIN32
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#endif
+#include <chrono>
+#include <thread>
 
 #include <hugin.hpp>
-
-#include <notifier.h>
 #include <settings.h>
 
-class TestMain : public Listener {
-public:
-	TestMain()
-	{
-		CONNECT(&gui, closeNotifier, this, &TestMain::stop);
-	}
-
-	void stop()
-	{
-		DEBUG(stop, "Stopping...\n");
-		running = false;
-	}
-
-	void run()
-	{
-		while(running)
-		{
-#ifdef WIN32
-			SleepEx(50, FALSE);
-#else
-			usleep(50000);
-#endif
-			gui.processEvents();
-		}
-	}
-
-	bool running = true;
-
-	Settings settings;
-	GUI::PluginGUI gui{settings};
-};
+#include "mainwindow.h"
+#include "window.h"
 
 int main()
 {
 	INFO(example, "We are up and running");
 
-	TestMain testMain;
-	testMain.run();
+	GUI::Window parent{nullptr};
+	parent.setCaption("PluginGui Test Application");
+
+	Settings settings;
+	GUI::MainWindow main_window(settings, parent.getNativeWindowHandle());
+	CONNECT(&parent, eventHandler()->closeNotifier, &main_window,
+	    &GUI::MainWindow::closeEventHandler);
+
+	parent.show();
+	main_window.show();
+
+	parent.resize(750, 400);
+
+	while(true)
+	{
+		parent.eventHandler()->processEvents();
+		if(!main_window.processEvents())
+		{
+			break;
+		}
+
+		std::this_thread::sleep_for(std::chrono::milliseconds(50));
+	}
 
 	return 0;
 }
