@@ -35,7 +35,10 @@
 
 #include "audiocachefile.h"
 
-#define CHUNKSIZE(x) (x * CHUNK_MULTIPLIER)
+AudioCache::AudioCache(Settings& settings)
+	: settings(settings)
+{
+}
 
 AudioCache::~AudioCache()
 {
@@ -47,7 +50,7 @@ AudioCache::~AudioCache()
 	DEBUG(cache, "~AudioCache() post\n");
 }
 
-void AudioCache::init(size_t poolsize)
+void AudioCache::init(std::size_t poolsize)
 {
 	setAsyncMode(true);
 
@@ -61,11 +64,15 @@ void AudioCache::deinit()
 }
 
 // Invariant: initial_samples_needed < preloaded audio data
-sample_t* AudioCache::open(const AudioFile& file, size_t initial_samples_needed,
+sample_t* AudioCache::open(const AudioFile& file,
+                           std::size_t initial_samples_needed,
                            int channel, cacheid_t& id)
 {
+	assert(chunk_size); // Assert updateChunkSize was called before processing.
+
 	if(!file.isValid())
 	{
+		settings.number_of_underruns.fetch_add(1);
 		// File preload not yet ready - skip this sample.
 		id = CACHE_DUMMYID;
 		assert(nodata);
@@ -78,6 +85,7 @@ sample_t* AudioCache::open(const AudioFile& file, size_t initial_samples_needed,
 	// If we are out of available ids we get CACHE_DUMMYID
 	if(id == CACHE_DUMMYID)
 	{
+		settings.number_of_underruns.fetch_add(1);
 		// Use nodata buffer instead.
 		assert(nodata);
 		return nodata;
@@ -92,10 +100,11 @@ sample_t* AudioCache::open(const AudioFile& file, size_t initial_samples_needed,
 	// Next call to 'next()' will read from this point.
 	c.localpos = initial_samples_needed;
 
+	c.ready = false;
 	c.front = nullptr; // This is allocated when needed.
 	c.back = nullptr; // This is allocated when needed.
 
-	size_t cropped_size;
+	std::size_t cropped_size;
 
 	if(file.preloadedsize == file.size)
 	{
@@ -131,7 +140,7 @@ sample_t* AudioCache::open(const AudioFile& file, size_t initial_samples_needed,
 
 		if(c.back == nullptr)
 		{
-			c.back = new sample_t[CHUNKSIZE(framesize)];
+			c.back = new sample_t[chunk_size];
 		}
 
 		event_handler.pushLoadNextEvent(c.afile, c.channel, c.pos,
@@ -141,12 +150,13 @@ sample_t* AudioCache::open(const AudioFile& file, size_t initial_samples_needed,
 	return c.preloaded_samples; // return preloaded data
 }
 
-sample_t* AudioCache::next(cacheid_t id, size_t& size)
+sample_t* AudioCache::next(cacheid_t id, std::size_t& size)
 {
 	size = framesize;
 
 	if(id == CACHE_DUMMYID)
 	{
+		settings.number_of_underruns.fetch_add(1);
 		assert(nodata);
 		return nodata;
 	}
@@ -168,7 +178,6 @@ sample_t* AudioCache::next(cacheid_t id, size_t& size)
 			}
 
 			c.localpos += framesize;
-
 			return s;
 		}
 
@@ -179,8 +188,17 @@ sample_t* AudioCache::next(cacheid_t id, size_t& size)
 	{
 
 		// We are playing from cache:
-		if(c.localpos < CHUNKSIZE(framesize))
+		if(c.localpos < chunk_size)
 		{
+			if(c.front == nullptr)
+			{
+				// Just return silence.
+				settings.number_of_underruns.fetch_add(1);
+				c.localpos += framesize; // Skip these samples so we don't loose sync.
+				assert(nodata);
+				return nodata;
+			}
+
 			sample_t* s = c.front + c.localpos;
 			c.localpos += framesize;
 			return s;
@@ -191,7 +209,9 @@ sample_t* AudioCache::next(cacheid_t id, size_t& size)
 	if(!c.ready)
 	{
 		// Just return silence.
-		++number_of_underruns;
+		settings.number_of_underruns.fetch_add(1);
+		c.localpos += framesize; // Skip these samples so we don't loose sync.
+		assert(nodata);
 		return nodata;
 	}
 
@@ -201,7 +221,7 @@ sample_t* AudioCache::next(cacheid_t id, size_t& size)
 	// Next time we go here we have already read the first frame.
 	c.localpos = framesize;
 
-	c.pos += CHUNKSIZE(framesize);
+	c.pos += chunk_size;
 
 	// Does the file have remaining unread samples?
 	assert(c.afile); // Assert that we have an audio file.
@@ -210,7 +230,7 @@ sample_t* AudioCache::next(cacheid_t id, size_t& size)
 		// Do we have a back buffer to read into?
 		if(c.back == nullptr)
 		{
-			c.back = new sample_t[CHUNKSIZE(framesize)];
+			c.back = new sample_t[chunk_size];
 		}
 
 		event_handler.pushLoadNextEvent(c.afile, c.channel, c.pos,
@@ -244,7 +264,7 @@ void AudioCache::close(cacheid_t id)
 	event_handler.pushCloseEvent(id);
 }
 
-void AudioCache::setFrameSize(size_t framesize)
+void AudioCache::setFrameSize(std::size_t framesize)
 {
 	DEBUG(cache, "%s\n", __PRETTY_FUNCTION__);
 
@@ -255,27 +275,46 @@ void AudioCache::setFrameSize(size_t framesize)
 	// NOTE: Not threaded...
 	//std::lock_guard<AudioCacheIDManager> id_manager_lock(id_manager);
 
-	if(framesize > this->framesize)
+	if(framesize > nodata_framesize)
 	{
-		delete[] nodata;
+		if(nodata)
+		{
+			nodata_dirty.emplace_back(std::move(nodata)); // Store for later deletion.
+		}
 		nodata = new sample_t[framesize];
+		nodata_framesize = framesize;
 
-		for(size_t i = 0; i < framesize; ++i)
+		for(std::size_t i = 0; i < framesize; ++i)
 		{
 			nodata[i] = 0.0f;
 		}
 	}
 
 	this->framesize = framesize;
-
-	event_handler.setChunkSize(CHUNKSIZE(framesize));
 }
 
-size_t AudioCache::getFrameSize() const
+std::size_t AudioCache::getFrameSize() const
 {
 	return framesize;
 }
 
+void AudioCache::updateChunkSize(std::size_t output_channels)
+{
+	// Make sure we won't get out-of-range chunk sizes.
+	std::size_t disk_cache_chunk_size =
+		std::max(settings.disk_cache_chunk_size.load(), std::size_t(512u * 1024u));
+	output_channels = std::max(output_channels, std::size_t(1u));
+
+	// 1MB pr. chunk divided over 16 channels, 4 bytes pr. sample.
+	const auto ideal_chunk_size =
+		disk_cache_chunk_size / output_channels / sizeof(sample_t);
+
+	// Chunk size must match a whole number of frames.
+	chunk_size = (ideal_chunk_size / framesize) * framesize;
+
+	event_handler.setChunkSize(chunk_size);
+}
+
 void AudioCache::setAsyncMode(bool async)
 {
 	event_handler.setThreaded(async);
@@ -285,13 +324,3 @@ bool AudioCache::isAsyncMode() const
 {
 	return event_handler.isThreaded();
 }
-
-size_t AudioCache::getNumberOfUnderruns() const
-{
-	return number_of_underruns;
-}
-
-void AudioCache::resetNumberOfUnderruns()
-{
-	number_of_underruns = 0;
-}
