@@ -29,6 +29,7 @@
 #include <string>
 #include <list>
 #include <vector>
+#include <memory>
 
 #include "audiotypes.h"
 #include "audiofile.h"
@@ -36,12 +37,12 @@
 #include "audiocachefile.h"
 #include "audiocacheidmanager.h"
 #include "audiocacheeventhandler.h"
+#include "settings.h"
 
-#define CHUNK_MULTIPLIER 16
-
-class AudioCache {
+class AudioCache
+{
 public:
-	AudioCache() = default;
+	AudioCache(Settings& settings);
 
 	//! Destroy object and stop thread if needed.
 	~AudioCache();
@@ -50,7 +51,7 @@ public:
 	//! This method starts the cache manager thread.
 	//! This method blocks until the thread has been started.
 	//! \param poolsize The maximum number of parellel events supported.
-	void init(size_t poolsize);
+	void init(std::size_t poolsize);
 
 	//! Stop thread and clean up resources.
 	//! This method blocks until the thread has stopped.
@@ -67,7 +68,7 @@ public:
 	//! \param [out] new_id The newly created cache id.
 	//! \return A pointer to the first buffer containing the
 	//!  'initial_samples_needed' number of samples.
-	sample_t* open(const AudioFile& file, size_t initial_samples_needed, int channel,
+	sample_t* open(const AudioFile& file, std::size_t initial_samples_needed, int channel,
 	               cacheid_t& new_id);
 
 	//! Get next buffer.
@@ -77,7 +78,7 @@ public:
 	//! \param id The cache id to read from.
 	//! \param [out] size The size of the returned buffer.
 	//! \return A pointer to the buffer.
-	sample_t* next(cacheid_t id, size_t &size);
+	sample_t* next(cacheid_t id, std::size_t &size);
 
 	//! Returns true iff the next chunk of the supplied id has been read from disk.
 	bool isReady(cacheid_t id);
@@ -88,8 +89,12 @@ public:
 	void close(cacheid_t id);
 
 	//! Set/get internal framesize used when iterating through cache buffers.
-	void setFrameSize(size_t framesize);
-	size_t getFrameSize() const;
+	void setFrameSize(std::size_t framesize);
+	std::size_t getFrameSize() const;
+
+	//! Signal the AudioCache sub-system to set it's internals according to the
+	//! chunk size parameter from Settings.
+	void updateChunkSize(std::size_t output_channels);
 
 	//! Control/get reader threaded mode.
 	//! True means reading happening threaded, false means all reading done
@@ -97,17 +102,15 @@ public:
 	void setAsyncMode(bool async);
 	bool isAsyncMode() const;
 
-	//! Return the number of chunks that were read too late.
-	size_t getNumberOfUnderruns() const;
-
-	//! Set underrun counter to 0.
-	void resetNumberOfUnderruns();
-
 private:
-	size_t framesize{0};
+	std::size_t framesize{0};
 	sample_t* nodata{nullptr};
-	size_t number_of_underruns{0};
+	std::size_t nodata_framesize{0};
+	std::size_t chunk_size{0};
+	std::list<std::unique_ptr<sample_t[]>> nodata_dirty;
 
 	AudioCacheIDManager id_manager;
 	AudioCacheEventHandler event_handler{id_manager};
+
+	Settings& settings;
 };
