@@ -37,7 +37,6 @@
 #include "drumkit.h"
 #include "drumkitloader.h"
 #include "audiocache.h"
-#include "mutex.h"
 #include "chresampler.h"
 #include "settings.h"
 #include "inputprocessor.h"
@@ -79,8 +78,6 @@ private:
 protected:
 	DrumKitLoader loader;
 
-	Mutex mutex;
-
 	AudioOutputEngine& oe;
 	AudioInputEngine& ie;
 
@@ -89,17 +86,20 @@ protected:
 	Resamplers resamplers;
 	sample_t resampler_output_buffer[MAX_NUM_CHANNELS][RESAMPLER_OUTPUT_BUFFER];
 	sample_t resampler_input_buffer[MAX_NUM_CHANNELS][RESAMPLER_INPUT_BUFFER];
+	bool enable_resampling{true};
 
 	std::map<std::string, AudioFile *> audiofiles;
 
-	AudioCache audioCache;
+	AudioCache audio_cache;
 	DrumKit kit;
 	InputProcessor input_processor;
 
-	size_t framesize;
-	bool freewheel;
+	size_t framesize{0};
+	bool freewheel{true};
 
 	std::vector<event_t> events;
 	Settings& settings;
+	SettingsGetter settings_getter;
+
 	Random rand;
 };
