@@ -37,13 +37,15 @@
 DrumKitLoader::DrumKitLoader(Settings& settings, DrumKit& kit,
                              AudioInputEngine& ie,
                              Resamplers& resamplers,
-                             Random& rand)
+                             Random& rand,
+                             AudioCache& audio_cache)
 	: settings(settings)
 	, getter(settings)
 	, kit(kit)
 	, ie(ie)
 	, resamplers(resamplers)
 	, rand(rand)
+	, audio_cache(audio_cache)
 {
 }
 
@@ -83,11 +85,14 @@ bool DrumKitLoader::loadkit(const std::string& file)
 
 	if(file == "")
 	{
-		settings.drumkit_load_status.store(LoadStatus::Error);
+		if (getter.reload_counter.getValue() != 0)
+		{
+			settings.drumkit_load_status.store(LoadStatus::Error);
 
-		// Show a full bar
-		settings.number_of_files.store(1);
-		settings.number_of_files_loaded.store(1);
+			// Show a full bar
+			settings.number_of_files.store(1);
+			settings.number_of_files_loaded.store(1);
+		}
 
 		return false;
 	}
@@ -123,12 +128,18 @@ bool DrumKitLoader::loadkit(const std::string& file)
 		       "Trying to load it anyway...\n");
 	}
 
+	// Put some information about the kit into the settings
+	settings.drumkit_name = kit.getName();
+	settings.drumkit_description = kit.getDescription();
+	settings.drumkit_version = kit.getVersion();
+	settings.drumkit_samplerate = kit.getSamplerate();
+
 	loadKit(&kit);
 
 #ifdef WITH_RESAMPLER
 	resamplers.setup(kit.getSamplerate(), settings.samplerate.load());
 #endif/*WITH_RESAMPLER*/
-
+	settings.resamplig_recommended.store(resamplers.isActive());
 
 	DEBUG(loadkit, "loadkit: Success\n");
 
@@ -141,6 +152,37 @@ void DrumKitLoader::loadKit(DrumKit *kit)
 
 	DEBUG(loader, "Create AudioFile queue from DrumKit\n");
 
+	auto cache_limit = settings.disk_cache_upper_limit.load();
+	auto cache_enable = settings.disk_cache_enable.load();
+
+	DEBUG(loader, "cache_enable: %s\n", cache_enable?"true":"false");
+
+	if(cache_enable)
+	{
+		auto number_of_files = kit->getNumberOfFiles();
+		auto cache_limit_per_file = cache_limit / number_of_files;
+
+		assert(framesize != 0);
+
+		preload_samples = cache_limit_per_file / sizeof(sample_t);
+
+		if(preload_samples < 4096)
+		{
+			preload_samples = 4096;
+		}
+
+		DEBUG(loader, "cache_limit: %lu, number_of_files: %lu,"
+		      " cache_limit_per_file: %lu, preload_samples: %lu\n",
+		      (unsigned long)cache_limit,
+		      (unsigned long)number_of_files,
+		      (unsigned long)cache_limit_per_file,
+		      (unsigned long)preload_samples);
+	}
+	else
+	{
+		preload_samples = std::numeric_limits<std::size_t>::max();
+	}
+
 	settings.number_of_files_loaded.store(0);
 
 	// Count total number of files that need loading:
@@ -162,6 +204,8 @@ void DrumKitLoader::loadKit(DrumKit *kit)
 	DEBUG(loader, "Queued %d (size: %d) AudioFiles for loading.\n",
 	      (int)settings.number_of_files.load(), (int)load_queue.size());
 
+	audio_cache.updateChunkSize(kit->channels.size());
+
 	semaphore.post(); // Start loader loop.
 }
 
@@ -171,7 +215,7 @@ void DrumKitLoader::skip()
 	load_queue.clear();
 }
 
-void DrumKitLoader::setFrameSize(size_t framesize)
+void DrumKitLoader::setFrameSize(std::size_t framesize)
 {
 	std::lock_guard<std::mutex> guard(mutex);
 	this->framesize = framesize;
@@ -188,7 +232,7 @@ void DrumKitLoader::thread_main()
 
 	while(running)
 	{
-		size_t size;
+		std::size_t size;
 		{
 			std::lock_guard<std::mutex> guard(mutex);
 			size = load_queue.size();
@@ -197,11 +241,12 @@ void DrumKitLoader::thread_main()
 		// Only sleep if queue is empty.
 		if(size == 0)
 		{
-			semaphore.wait(std::chrono::milliseconds(1000));
+			semaphore.wait(std::chrono::milliseconds(10));
 		}
 
 		bool newKit = false;
-		if(getter.drumkit_file.hasChanged())
+		if(getter.drumkit_file.hasChanged() ||
+		   getter.reload_counter.hasChanged())
 		{
 			loadkit(getter.drumkit_file.getValue());
 			newKit = true;
@@ -210,8 +255,11 @@ void DrumKitLoader::thread_main()
 		if(getter.midimap_file.hasChanged() || newKit)
 		{
 			auto ie_midi = dynamic_cast<AudioInputEngineMidi*>(&ie);
-			std::cout << "ie_midi: " << (void*)ie_midi << std::endl;
-			if(ie_midi)
+
+			// if there's a midi engine and this is not just the default midimap
+			// name which is set.
+			if(ie_midi && (getter.midimap_file.getValue() != "" ||
+						   getter.reload_counter.getValue() != 0))
 			{
 				settings.midimap_load_status.store(LoadStatus::Loading);
 				bool ret = ie_midi->loadMidiMap(getter.midimap_file.getValue(),
@@ -239,16 +287,15 @@ void DrumKitLoader::thread_main()
 			AudioFile *audiofile = load_queue.front();
 			load_queue.pop_front();
 			filename = audiofile->filename;
-			int preload_size = framesize * CHUNK_MULTIPLIER + framesize;
-			if(preload_size < 1024)
+			try
 			{
-				preload_size = 1024;
+				audiofile->load(preload_samples);
+			}
+			catch(std::bad_alloc&)
+			{
+				settings.drumkit_load_status.store(LoadStatus::Error);
+				load_queue.clear();
 			}
-
-			// Note: Remove this line to enable diskstreaming
-			preload_size = ALL_SAMPLES;
-
-			audiofile->load(preload_size);
 		}
 
 		settings.number_of_files_loaded.fetch_add(1);
