@@ -28,7 +28,7 @@
 
 #include "inputfilter.h"
 
-class Settings;
+struct Settings;
 
 class LatencyFilter
 	: public InputFilter
@@ -41,5 +41,5 @@ public:
 	std::size_t getLatency() const override;
 
 private:
-	Settings& settings;
+	//Settings& settings;
 };
