@@ -26,27 +26,14 @@
  */
 #include "midimapparser.h"
 
-MidiMapParser::MidiMapParser(std::string file)
+void MidiMapParser::startTag(const std::string& name, const attr_t& attr)
 {
-  fd = fopen(file.c_str(), "r");
-}
-
-MidiMapParser::~MidiMapParser()
-{
-  if(fd) fclose(fd);
-}
-
-void MidiMapParser::startTag(std::string name, attr_t attr)
-{
-  if(name == "map") {
-    if(attr.find("note") != attr.end() && attr.find("instr") != attr.end()) {
-      midimap[atoi(attr["note"].c_str())] = attr["instr"];
-    }
-  }
-}
-
-int MidiMapParser::readData(char *data, size_t size)
-{
-  if(!fd) return -1;
-  return fread(data, 1, size, fd);
+	if(name == "map")
+	{
+		if((attr.find("note") != attr.end()) &&
+		   (attr.find("instr") != attr.end()))
+		{
+			midimap[std::stoi(attr.at("note"))] = attr.at("instr");
+		}
+	}
 }
