@@ -24,29 +24,16 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_MIDIMAPPARSER_H__
-#define __DRUMGIZMO_MIDIMAPPARSER_H__
-
-#include <stdio.h>
+#pragma once
 
 #include "saxparser.h"
-
 #include "midimapper.h"
 
-class MidiMapParser : public SAXParser {
+class MidiMapParser
+	: public SAXParser
+{
 public:
-  MidiMapParser(std::string file);
-  ~MidiMapParser();
+	void startTag(const std::string& name, const attr_t& attr) override;
 
-  void startTag(std::string name, attr_t attr);
-
-  midimap_t midimap;
-
-protected:
-  int readData(char *data, size_t size);
-
-private:
-  FILE *fd;
+	midimap_t midimap;
 };
-
-#endif/*__DRUMGIZMO_MIDIMAPPARSER_H__*/
