@@ -24,35 +24,36 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_POWERLIST_H__
-#define __DRUMGIZMO_POWERLIST_H__
+#pragma once
 
 #include <vector>
 
 #include "sample.h"
+#include "random.h"
 
-class PowerList {
+class PowerList
+{
 public:
-  PowerList();
+	PowerList(Random& rand);
 
-  void add(Sample *s);
-  void finalise(); ///< Call this when no more samples will be added.
-
-  Sample *get(level_t velocity);
+	void add(Sample* s);
+	void finalise(); ///< Call this when no more samples will be added.
+	
+	Sample* get(level_t velocity);
 
 private:
-  class PowerListItem {
-  public:
-    Sample *sample;
-    float power;
-  };
+	struct PowerListItem
+	{
+		Sample* sample;
+		float power;
+	};
 
-  std::vector<PowerListItem> samples;
-  float power_max;
-  float power_min;
+	Random& rand;
 
-  Channel *getMasterChannel();
-  Sample *lastsample;
+	std::vector<PowerListItem> samples;
+	float power_max;
+	float power_min;
+	
+	Channel* getMasterChannel();
+	Sample* lastsample;
 };
-
-#endif/*__DRUMGIZMO_POWERLIST_H__*/
