@@ -24,34 +24,42 @@
  *  along with DrumGizmo; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
  */
-#ifndef __DRUMGIZMO_SAXPARSER_H__
-#define __DRUMGIZMO_SAXPARSER_H__
+#pragma once
 
 #include <string>
-#include <map>
+#include <unordered_map>
 #include <expat.h>
+#include <fstream>
 
-typedef std::map< std::string, std::string> attr_t;
-
-class SAXParser {
+class SAXParser
+{
 public:
-  SAXParser();
-  virtual ~SAXParser();
+	SAXParser();
+	virtual ~SAXParser();
 
-  int parse();
-  int parse(std::string buffer);
-  
-  virtual void characterData(std::string &data) {}
-  virtual void startTag(std::string name, attr_t attr) {}
-  virtual void endTag(std::string name) {}
+	//! Parses the data from the file.
+	virtual int parseFile(const std::string& filename);
 
-  virtual void parseError(char *buf, size_t len, std::string error, int lineno);
+	//! Parses all the data in the buffer.
+	virtual int parseString(const std::string& str,
+	                        const std::string& xml_source_name = "");
 
 protected:
-  virtual int readData(char *data, size_t size) { return 0; }
+	using attr_t = std::unordered_map<std::string, std::string>;
+
+	virtual void characterData(const std::string& data) {}
+	virtual void startTag(const std::string& name, const attr_t& attr) {}
+	virtual void endTag(const std::string& name) {}
+	virtual void parseError(const std::string& buf,
+	                        const std::string& error,
+	                        const std::string& xml_source_name,
+	                        std::size_t lineno);
 
 private:
-  XML_Parser p;
-};
+	XML_Parser parser;
+	std::string filename;
 
-#endif/*__DRUMGIZMO_SAXPARSER_H__*/
+	static void characterHandler(void* parser, const XML_Char* cData, int len);
+	static void startHandler(void* parser, const char* el, const char** attr);
+	static void endHandler(void* parser, const char* el);
+};
