@@ -26,11 +26,13 @@
  */
 #include <cppunit/extensions/HelperMacros.h>
 
-#include <unistd.h>
+#include <thread>
+#include <chrono>
 #include <memory.h>
 #include <stdio.h>
 #include <arpa/inet.h>
 
+#include "drumkit_creator.h"
 #include "lv2_test_host.h"
 
 #define DG_URI "http://drumgizmo.org/lv2"
@@ -61,6 +63,8 @@ class test_lv2 : public CppUnit::TestFixture
 	CPPUNIT_TEST(test1);
 	CPPUNIT_TEST_SUITE_END();
 
+	DrumkitCreator drumkit_creator;
+
 public:
 	void setUp() {}
 	void tearDown() {}
@@ -108,8 +112,10 @@ public:
 			"  <value name=\"enable_resampling\">%s</value>\n"
 			"</config>";
 
-		const char drumkitfile[] = "kit/kit1.xml";
-		const char midimapfile[] = "kit/midimap.xml";
+		// Create drumkit
+		auto kit1_file = drumkit_creator.createStdKit("kit1");
+
+		auto midimapfile = drumkit_creator.createStdMidimap("midimap");
 		bool enable_velocity_modifier = true;
 		float velocity_modifier_falloff = 0.5;
 		float velocity_modifier_weight = 0.25;
@@ -119,8 +125,8 @@ public:
 
 		char config[sizeof(config_fmt) * 2];
 		sprintf(config, config_fmt,
-		        drumkitfile,
-		        midimapfile,
+		        kit1_file.c_str(),
+		        midimapfile.c_str(),
 		        enable_velocity_modifier?"true":"false",
 		        velocity_modifier_falloff,
 		        velocity_modifier_weight,
@@ -134,7 +140,7 @@ public:
 		// run for 1 samples to trigger kit loading
 		res = h.run(1);
 		CPPUNIT_ASSERT_EQUAL(0, res);
-		usleep(1000); // wait for kit to get loaded (async),
+		std::this_thread::sleep_for(std::chrono::milliseconds(1)); // wait for kit to get loaded (async),
 
 		res = h.run(100);
 		CPPUNIT_ASSERT_EQUAL(0, res);
@@ -173,8 +179,10 @@ public:
 			"  <value name=\"enable_resampling\">%s</value>\n"
 			"</config>";
 
-		const char drumkitfile[] = "kit/kit1.xml";
-		const char midimapfile[] = "kit/midimap.xml";
+		// Create drumkit
+		auto kit1_file = drumkit_creator.createStdKit("kit1");
+
+		auto midimapfile = drumkit_creator.createStdMidimap("midimap");
 		bool enable_velocity_modifier = true;
 		float velocity_modifier_falloff = 0.5;
 		float velocity_modifier_weight = 0.25;
@@ -184,8 +192,8 @@ public:
 
 		char config[sizeof(config_fmt) * 2];
 		sprintf(config, config_fmt,
-		        drumkitfile,
-		        midimapfile,
+		        kit1_file.c_str(),
+		        midimapfile.c_str(),
 		        enable_velocity_modifier?"true":"false",
 		        velocity_modifier_falloff,
 		        velocity_modifier_weight,
@@ -210,7 +218,7 @@ public:
 		// run for 1 samples to trigger kit loading
 		res = h.run(1);
 		CPPUNIT_ASSERT_EQUAL(0, res);
-		usleep(1000); // wait for kit to get loaded (async),
+		std::this_thread::sleep_for(std::chrono::milliseconds(1)); // wait for kit to get loaded (async),
 
 		seq.addMidiNote(5, 1, 127);
 		res = h.run(100);
@@ -250,8 +258,10 @@ public:
 			"  <value name=\"enable_resampling\">%s</value>\n"
 			"</config>";
 
-		const char drumkitfile[] = "kit/kit1.xml";
-		const char midimapfile[] = "kit/midimap.xml";
+		// Create drumkit
+		auto kit1_file = drumkit_creator.createStdKit("kit1");
+
+		auto midimapfile = drumkit_creator.createStdMidimap("midimap");
 		bool enable_velocity_modifier = true;
 		float velocity_modifier_falloff = 0.5;
 		float velocity_modifier_weight = 0.25;
@@ -261,8 +271,8 @@ public:
 
 		char config[sizeof(config_fmt) * 2];
 		sprintf(config, config_fmt,
-		        drumkitfile,
-		        midimapfile,
+		        kit1_file.c_str(),
+		        midimapfile.c_str(),
 		        enable_velocity_modifier?"true":"false",
 		        velocity_modifier_falloff,
 		        velocity_modifier_weight,
@@ -298,13 +308,13 @@ public:
 		// run for 1 samples to trigger kit loading
 		res = h.run(1);
 		CPPUNIT_ASSERT_EQUAL(0, res);
-		sleep(1); // wait for kit to get loaded (async),
+		std::this_thread::sleep_for(std::chrono::seconds(1));  // wait for kit to get loaded (async),
 
 		seq.addMidiNote(5, 1, 127);
 		for(int i = 0; i < 10; i++)
 		{
 			res = h.run(10);
-			usleep(1000);
+			std::this_thread::sleep_for(std::chrono::milliseconds(1));
 			CPPUNIT_ASSERT_EQUAL(0, res);
 
 			//printf("Iteration:\n");
@@ -321,7 +331,7 @@ public:
 
 		seq.addMidiNote(5, 1, 127);
 		res = h.run(10);
-		usleep(1000);
+		std::this_thread::sleep_for(std::chrono::milliseconds(1));
 		CPPUNIT_ASSERT_EQUAL(0, res);
 
 		/*
